@@ -4,6 +4,8 @@ from typing import List, Optional, Union
 import wizwalker
 
 
+# TODO: add way to cast divide spells (remember to click the confirm button after targeting)
+#  cast_divide?
 class CombatCard:
     """
     Represents a spell card
@@ -21,14 +23,16 @@ class CombatCard:
         self,
         target: Union["CombatCard", "wizwalker.combat.CombatMember", None],
         *,
-        sleep_time: Optional[float] = 1.0
+        sleep_time: Optional[float] = 1.0,
+        debug_paint: bool = False,
     ):
         """
         Cast this Card on another Card; a Member or with no target
 
         Args:
             target: Card, Member, or None if there is no target
-            sleep_time: how long to sleep after enchants and between multicasts or None for no sleep
+            sleep_time: How long to sleep after enchants and between multicasts or None for no sleep
+            debug_paint: If the card should be highlighted before clicking
         """
         if isinstance(target, CombatCard):
             cards_len_before = len(await self.combat_handler.get_cards())
@@ -45,6 +49,9 @@ class CombatCard:
 
             await asyncio.sleep(sleep_time)
 
+            if debug_paint:
+                await target._spell_window.debug_paint()
+
             await self.combat_handler.client.mouse_handler.click_window(
                 target._spell_window
             )
@@ -95,6 +102,7 @@ class CombatCard:
         if sleep_time is not None:
             await asyncio.sleep(sleep_time)
 
+    # TODO: 2.0 rename get_* effects to just attr name i.e async def graphical_spell
     async def get_graphical_spell(
         self,
     ) -> "wizwalker.memory.memory_objects.spell.DynamicGraphicalSpell":
@@ -107,40 +115,70 @@ class CombatCard:
 
         return res
 
+    async def wait_for_graphical_spell(
+        self,
+    ) -> "wizwalker.memory.memory_objects.spell.DynamicGraphicalSpell":
+        """
+        Wait for GraphicalSpell
+        """
+        return await wizwalker.utils.wait_for_non_error(self.get_graphical_spell)
+
     async def get_spell_effects(
         self,
     ) -> List["wizwalker.memory.memory_objects.spell_effect.DynamicSpellEffect"]:
-        spell = await self.get_graphical_spell()
+        spell = await self.wait_for_graphical_spell()
         return await spell.spell_effects()
 
     async def name(self) -> str:
         """
         The name of this card
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         spell_template = await graphical_spell.spell_template()
-        # name is the actual name; display name is local lang code
         return await spell_template.name()
 
+    async def display_name_code(self) -> str:
+        """
+        The display name code of this card
+        """
+        graphical_spell = await self.wait_for_graphical_spell()
+        spell_template = await graphical_spell.spell_template()
+        return await spell_template.display_name()
+
+    async def display_name(self) -> str:
+        """
+        the display name of this card
+        """
+        code = await self.display_name_code()
+        return await self.combat_handler.client.cache_handler.get_langcode_name(code)
+
+    async def type_name(self) -> str:
+        """
+        The type name of this card
+        """
+        graphical_spell = await self.wait_for_graphical_spell()
+        spell_template = await graphical_spell.spell_template()
+        return await spell_template.type_name()
+
     async def template_id(self) -> int:
         """
         This card's template id
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.template_id()
 
     async def spell_id(self) -> int:
         """
         This card's spell id
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.spell_id()
 
     async def accuracy(self) -> int:
         """
         Current accuracy of this card
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.accuracy()
 
     async def is_castable(self) -> bool:
@@ -154,47 +192,47 @@ class CombatCard:
         """
         If this card is enchanted or not
         """
-        grapical_spell = await self.get_graphical_spell()
+        grapical_spell = await self.wait_for_graphical_spell()
         return await grapical_spell.enchantment() != 0
 
     async def is_treasure_card(self) -> bool:
         """
         If this card is a treasure card
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.treasure_card()
 
     async def is_item_card(self) -> bool:
         """
         If this card is an item card
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.item_card()
 
     async def is_side_board(self) -> bool:
         """
         If this card is from the side deck
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.side_board()
 
     async def is_cloaked(self) -> bool:
         """
         If this card is cloaked
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.cloaked()
 
     async def is_enchanted_from_item_card(self) -> bool:
         """
         If this card was enchanted from an item card
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.enchantment_spell_is_item_card()
 
     async def is_pve_only(self) -> bool:
         """
         If this card can only be used in pve
         """
-        graphical_spell = await self.get_graphical_spell()
+        graphical_spell = await self.wait_for_graphical_spell()
         return await graphical_spell.pve()
