@@ -249,19 +249,21 @@ class QuestHook(SimpleHook):
 
 
 class DuelHook(SimpleHook):
-    pattern = rb"\x48\x89\x4C\x24\x50\x4C\x89\x74\x24\x48"
+    pattern = (
+        rb"\x48\x89\x7C\x24\x58\x48\x89\x4C\x24\x50\x4C\x89\x7C\x24\x48\x89\x5C\x24\x40"
+    )
     exports = [("current_duel_addr", 8)]
 
     async def bytecode_generator(self, packed_exports):
         # fmt: off
         bytecode = (
                 b"\x48\x39\xD1"  # cmp rcx,rdx
-                b"\x0F\x85\x0F\x00\x00\x00"  # jne 15
+                b"\x0F\x85\x10\x00\x00\x00"  # jne 16
                 b"\x50"  # push rax
-                b"\x49\x8B\x07"  # mov rax,[r15]
+                b"\x49\x8B\x04\x24"  # mov rax,[r12]
                 b"\x48\xA3" + packed_exports[0][1] +  # mov [current_duel],rax
                 b"\x58"  # pop rax
-                b"\x48\x89\x4C\x24\x50"  # original instruction
+                b"\x48\x89\x7C\x24\x58"  # original instruction
         )
         # fmt: on
 
