@@ -10,13 +10,31 @@ import subprocess
 import winreg
 import zlib
 from pathlib import Path
-from typing import Callable, Iterable, List
+from typing import Any, Callable, Iterable, List, Optional
 
 import appdirs
 
+from wizwalker import ExceptionalTimeout
 from wizwalker.constants import Keycode, kernel32, user32, gdi32
 
 
+async def async_sorted(iterable, /, *, key=None, reverse=False):
+    """
+    sorted but key function is awaited
+    """
+    if key is None:
+        return sorted(iterable, reverse=reverse)
+
+    evaluated = {}
+
+    for item in iterable:
+        evaluated[item] = await key(item)
+
+    return [
+        i[0] for i in sorted(evaluated.items(), key=lambda it: it[1], reverse=reverse)
+    ]
+
+
 class XYZ:
     def __init__(self, x: float, y: float, z: float):
         self.x = x
@@ -178,21 +196,20 @@ def get_wiz_install() -> Path:
     """
     Get the game install root dir
     """
-    reg = winreg.ConnectRegistry(None, winreg.HKEY_CURRENT_USER)
-
     try:
-        key = winreg.OpenKey(
-            reg,
+        with winreg.OpenKey(
+            winreg.HKEY_CURRENT_USER,
             r"Software\Microsoft\Windows\CurrentVersion\Uninstall\{A9E27FF5-6294-46A8-B8FD-77B1DECA3021}",
             0,
             winreg.KEY_READ,
-        )
+        ) as key:
+            install_location = Path(
+                winreg.QueryValueEx(key, "InstallLocation")[0]
+            ).absolute()
+            return install_location
     except OSError:
         raise Exception("Wizard101 install not found.")
 
-    install_location = Path(winreg.QueryValueEx(key, "InstallLocation")[0]).absolute()
-    return install_location
-
 
 def start_instance():
     """
@@ -315,15 +332,72 @@ async def wait_for_value(
 
         except Exception as e:
             if ignore_errors:
-                pass
+                await asyncio.sleep(sleep_time)
 
             else:
                 raise e
 
-        finally:
+
+async def wait_for_non_error(coro, sleep_time: float = 0.5):
+    """
+    Wait for a coro to not error
+
+    Args:
+        coro: Coro to wait for
+        sleep_time: Time between calls
+    """
+    while True:
+        # noinspection PyBroadException
+        try:
+            now = await coro()
+            return now
+
+        except Exception:
             await asyncio.sleep(sleep_time)
 
 
+async def maybe_wait_for_value_with_timeout(
+    coro,
+    sleep_time: float = 0.5,
+    *,
+    value: Any = None,
+    timeout: Optional[float] = None,
+    ignore_exceptions: bool = True,
+    inverse_value: bool = False,
+):
+    possible_exception = None
+
+    async def _inner():
+        nonlocal possible_exception
+
+        while True:
+            try:
+                res = await coro()
+                if value is not None and inverse_value and res != value:
+                    return res
+
+                elif value is not None and not inverse_value and res == value:
+                    return res
+
+                else:
+                    return res
+
+            except Exception as e:
+                if ignore_exceptions:
+                    possible_exception = e
+                    await asyncio.sleep(sleep_time)
+
+                else:
+                    raise e
+
+    try:
+        return await asyncio.wait_for(_inner(), timeout)
+    except asyncio.TimeoutError:
+        raise ExceptionalTimeout(
+            f"Timed out waiting for coro {coro.__name__}", possible_exception
+        )
+
+
 def get_cache_folder() -> Path:
     """
     Get the wizwalker cache folder
@@ -332,8 +406,7 @@ def get_cache_folder() -> Path:
     app_author = "StarrFox"
     cache_dir = Path(appdirs.user_cache_dir(app_name, app_author))
 
-    if not cache_dir.exists():
-        cache_dir.mkdir(parents=True)
+    cache_dir.mkdir(parents=True, exist_ok=True)
 
     return cache_dir
 
@@ -346,12 +419,34 @@ def get_logs_folder() -> Path:
     app_author = "StarrFox"
     log_dir = Path(appdirs.user_log_dir(app_name, app_author))
 
-    if not log_dir.exists():
-        log_dir.mkdir(parents=True)
+    log_dir.mkdir(parents=True, exist_ok=True)
 
     return log_dir
 
 
+def get_foreground_window() -> Optional[int]:
+    """
+    Get the window currently in the forground
+
+    Returns:
+        Handle to the window currently in the forground
+    """
+    return user32.GetForegroundWindow()
+
+
+def set_foreground_window(window_handle: int) -> bool:
+    """
+    Bring a window to the foreground
+
+    Args:
+        window_handle: Handle to the window to bring to the foreground
+
+    Returns:
+        False if the operation failed True otherwise
+    """
+    return user32.SetForegroundWindow(window_handle) != 0
+
+
 def get_window_title(handle: int, max_size: int = 100) -> str:
     """
     Get a window's title bar text
@@ -471,6 +566,7 @@ def get_windows_from_predicate(predicate: Callable) -> list:
     return handles
 
 
+# TODO: 2.0 move all these pharse functions to cache_handler, and rename them to parse instead of pharse
 def pharse_template_id_file(file_data: bytes) -> dict:
     """
     Pharse a template id file's data
